/**
 * The MIT License (MIT)
 *
 * Copyright (c) 2014-2022 Mickael Jeanroy
 *
 * Permission is hereby granted, free of charge, to any person obtaining a copy
 * of this software and associated documentation files (the "Software"), to deal
 * in the Software without restriction, including without limitation the rights
 * to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
 * copies of the Software, and to permit persons to whom the Software is
 * furnished to do so, subject to the following conditions:
 *
 * The above copyright notice and this permission notice shall be included in
 * all copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
 * THE SOFTWARE.
 */

import {assumeFreeze} from '../../../detect/assume-freeze.js';
import {assumePreventExtensions} from '../../../detect/assume-prevent-extensions.js';
import {assumeSeal} from '../../../detect/assume-seal.js';
import '../../../../src/index.js';

describe('toBeExtensible', () => {
  it('should not pass with primitive values', () => {
    expect(null).not.toBeExtensible();
    expect(undefined).not.toBeExtensible();
    expect('').not.toBeExtensible();
    expect(1).not.toBeExtensible();
    expect(true).not.toBeExtensible();
  });

  it('should pass with non frozen objects and array', () => {
    expect({}).toBeExtensible();
    expect([]).toBeExtensible();
  });

  it('should not pass with frozen objects and array', () => {
    assumeFreeze();

    expect(Object.freeze({})).not.toBeExtensible();
    expect(Object.freeze([])).not.toBeExtensible();
  });

  it('should not pass with sealed objects and array', () => {
    assumeSeal();

    expect(Object.seal({})).not.toBeExtensible();
    expect(Object.seal([])).not.toBeExtensible();
  });

  it('should not pass with non extensible objects and array', () => {
    assumePreventExtensions();

    expect(Object.preventExtensions({})).not.toBeExtensible();
    expect(Object.preventExtensions([])).not.toBeExtensible();
  });
});
