/**
 * The MIT License (MIT)
 *
 * Copyright (c) 2014-2022 Mickael Jeanroy
 *
 * Permission is hereby granted, free of charge, to any person obtaining a copy
 * of this software and associated documentation files (the "Software"), to deal
 * in the Software without restriction, including without limitation the rights
 * to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
 * copies of the Software, and to permit persons to whom the Software is
 * furnished to do so, subject to the following conditions:
 *
 * The above copyright notice and this permission notice shall be included in
 * all copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
 * THE SOFTWARE.
 */

import {toBeDOMElementWithId} from '../../../src/core/matchers/dom/to-be-dom-element-with-id.js';
import {createFakeContext} from '../../testing/create-fake-context.js';

describe('toBeDOMElementWithId', () => {
  let div;

  beforeEach(() => {
    div = document.createElement('div');
    div.setAttribute('id', 'foo');
  });

  it('should pass with a dom element with expected id', () => {
    const actual = div;
    const ctx = createFakeContext(actual);

    const result = toBeDOMElementWithId(ctx, 'foo');

    expect(result).toEqual({
      pass: true,
      message: jasmine.any(Function),
    });

    expect(result.message()).toBe(
        `Expect <div id="foo"> {{not}} to be a DOM element with id 'foo' but was 'foo'`
    );
  });

  it('should not pass without a DOM element', () => {
    const actual = '<div></div>';
    const ctx = createFakeContext(actual);

    const result = toBeDOMElementWithId(ctx, 'div');

    expect(result).toEqual({
      pass: false,
      message: jasmine.any(Function),
    });

    expect(result.message()).toBe(
        `Expect '<div></div>' {{not}} to be a DOM element`
    );
  });

  it('should not pass with a DOM element but not the expected id', () => {
    const actual = div;
    const ctx = createFakeContext(actual);

    const result = toBeDOMElementWithId(ctx, 'bar');

    expect(result).toEqual({
      pass: false,
      message: jasmine.any(Function),
    });

    expect(result.message()).toBe(
        `Expect <div id="foo"> {{not}} to be a DOM element with id 'bar' but was 'foo'`
    );
  });
});
